@@ -22,10 +22,11 @@
 #' @keywords endpoint
 #' @export
 pvt_cdc <- function(
-    auth,
-    locations,
-    epiweeks = "*",
-    fetch_args = fetch_args_list()) {
+  auth,
+  locations,
+  epiweeks = "*",
+  fetch_args = fetch_args_list()
+) {
   epiweeks <- get_wildcard_equivalent_dates(epiweeks, "week")
 
   assert_character_param("auth", auth, len = 1)
@@ -88,13 +89,14 @@ pvt_cdc <- function(
 #' @keywords endpoint
 #' @export
 pub_covid_hosp_facility_lookup <- function(
-    ...,
-    state = NULL,
-    ccn = NULL,
-    city = NULL,
-    zip = NULL,
-    fips_code = NULL,
-    fetch_args = fetch_args_list()) {
+  ...,
+  state = NULL,
+  ccn = NULL,
+  city = NULL,
+  zip = NULL,
+  fips_code = NULL,
+  fetch_args = fetch_args_list()
+) {
   rlang::check_dots_empty()
 
   assert_character_param("state", state, len = 1, required = FALSE)
@@ -182,11 +184,12 @@ pub_covid_hosp_facility_lookup <- function(
 #' @export
 #
 pub_covid_hosp_facility <- function(
-    hospital_pks,
-    collection_weeks = "*",
-    ...,
-    publication_dates = NULL,
-    fetch_args = fetch_args_list()) {
+  hospital_pks,
+  collection_weeks = "*",
+  ...,
+  publication_dates = NULL,
+  fetch_args = fetch_args_list()
+) {
   rlang::check_dots_empty()
 
   collection_weeks <- get_wildcard_equivalent_dates(collection_weeks, "day")
@@ -567,12 +570,13 @@ pub_covid_hosp_facility <- function(
 #' @export
 #
 pub_covid_hosp_state_timeseries <- function(
-    states,
-    dates = "*",
-    ...,
-    as_of = NULL,
-    issues = NULL,
-    fetch_args = fetch_args_list()) {
+  states,
+  dates = "*",
+  ...,
+  as_of = NULL,
+  issues = NULL,
+  fetch_args = fetch_args_list()
+) {
   # Check parameters
   rlang::check_dots_empty()
 
@@ -906,17 +910,17 @@ pub_covidcast_meta <- function(fetch_args = fetch_args_list()) {
       create_epidata_field_info(
         "geo_type",
         "categorical",
-        categories = c("nation", "msa", "hrr", "hhs", "state", "county", "dma")
+        categories = c("nation", "msa", "hrr", "hhs", "state", "county", "dma", "hsa_nci")
       ),
-      create_epidata_field_info("min_time", "date"),
-      create_epidata_field_info("max_time", "date"),
+      create_epidata_field_info("min_time", "int"),
+      create_epidata_field_info("max_time", "int"),
       create_epidata_field_info("num_locations", "int"),
       create_epidata_field_info("min_value", "float"),
       create_epidata_field_info("max_value", "float"),
       create_epidata_field_info("mean_value", "float"),
       create_epidata_field_info("stdev_value", "float"),
       create_epidata_field_info("last_update", "int"),
-      create_epidata_field_info("max_issue", "date"),
+      create_epidata_field_info("max_issue", "int"),
       create_epidata_field_info("min_lag", "int"),
       create_epidata_field_info("max_lag", "int")
     )
@@ -982,17 +986,18 @@ pub_covidcast_meta <- function(fetch_args = fetch_args_list()) {
 #' @keywords endpoint
 #' @export
 pub_covidcast <- function(
-    source,
-    signals,
-    geo_type,
-    time_type,
-    geo_values = "*",
-    time_values = "*",
-    ...,
-    as_of = NULL,
-    issues = NULL,
-    lag = NULL,
-    fetch_args = fetch_args_list()) {
+  source,
+  signals,
+  geo_type,
+  time_type,
+  geo_values = "*",
+  time_values = "*",
+  ...,
+  as_of = NULL,
+  issues = NULL,
+  lag = NULL,
+  fetch_args = fetch_args_list()
+) {
   rlang::check_dots_empty()
 
   # Check parameters
@@ -1035,6 +1040,17 @@ pub_covidcast <- function(
     )
   }
 
+  if (source == "nssp" && time_type != "week") {
+    cli::cli_abort(
+      "{source} data is only available at the week level",
+      class = "epidatr__nchs_week_only"
+    )
+  }
+
+  # TODO: This should probably be done in the create_epidata_call function. But
+  # this is a quick fix for now.
+  checkmate::assert_subset(time_type, c("day", "week"))
+
   create_epidata_call(
     "covidcast/",
     list(
@@ -1054,7 +1070,7 @@ pub_covidcast <- function(
       create_epidata_field_info(
         "geo_type",
         "categorical",
-        categories = c("nation", "msa", "hrr", "hhs", "state", "county")
+        categories = c("nation", "msa", "hrr", "hhs", "state", "county", "dma", "hsa_nci")
       ),
       create_epidata_field_info("time_type", "categorical",
         categories =
@@ -1097,9 +1113,10 @@ pub_covidcast <- function(
 #' @keywords endpoint
 #' @export
 pub_delphi <- function(
-    system,
-    epiweek,
-    fetch_args = fetch_args_list()) {
+  system,
+  epiweek,
+  fetch_args = fetch_args_list()
+) {
   assert_character_param("system", system)
   assert_timeset_param("epiweek", epiweek, len = 1)
   epiweek <- parse_timeset_input(epiweek)
@@ -1134,9 +1151,10 @@ pub_delphi <- function(
 #' @keywords endpoint
 #' @export
 pub_dengue_nowcast <- function(
-    locations,
-    epiweeks = "*",
-    fetch_args = fetch_args_list()) {
+  locations,
+  epiweeks = "*",
+  fetch_args = fetch_args_list()
+) {
   epiweeks <- get_wildcard_equivalent_dates(epiweeks, "week")
 
   assert_character_param("locations", locations)
@@ -1177,11 +1195,12 @@ pub_dengue_nowcast <- function(
 #' @keywords endpoint
 #' @export
 pvt_dengue_sensors <- function(
-    auth,
-    names,
-    locations,
-    epiweeks = "*",
-    fetch_args = fetch_args_list()) {
+  auth,
+  names,
+  locations,
+  epiweeks = "*",
+  fetch_args = fetch_args_list()
+) {
   epiweeks <- get_wildcard_equivalent_dates(epiweeks, "week")
 
   assert_character_param("auth", auth, len = 1)
@@ -1234,12 +1253,13 @@ pvt_dengue_sensors <- function(
 #' @keywords endpoint
 #' @export
 pub_ecdc_ili <- function(
-    regions,
-    epiweeks = "*",
-    ...,
-    issues = NULL,
-    lag = NULL,
-    fetch_args = fetch_args_list()) {
+  regions,
+  epiweeks = "*",
+  ...,
+  issues = NULL,
+  lag = NULL,
+  fetch_args = fetch_args_list()
+) {
   rlang::check_dots_empty()
 
   epiweeks <- get_wildcard_equivalent_dates(epiweeks, "week")
@@ -1301,12 +1321,13 @@ pub_ecdc_ili <- function(
 #' @keywords endpoint
 #' @export
 pub_flusurv <- function(
-    locations,
-    epiweeks = "*",
-    ...,
-    issues = NULL,
-    lag = NULL,
-    fetch_args = fetch_args_list()) {
+  locations,
+  epiweeks = "*",
+  ...,
+  issues = NULL,
+  lag = NULL,
+  fetch_args = fetch_args_list()
+) {
   rlang::check_dots_empty()
 
   epiweeks <- get_wildcard_equivalent_dates(epiweeks, "week")
@@ -1340,7 +1361,30 @@ pub_flusurv <- function(
       create_epidata_field_info("rate_age_2", "float"),
       create_epidata_field_info("rate_age_3", "float"),
       create_epidata_field_info("rate_age_4", "float"),
-      create_epidata_field_info("rate_overall", "float")
+      create_epidata_field_info("rate_overall", "float"),
+      create_epidata_field_info("rate_age_5", "float"),
+      create_epidata_field_info("rate_age_6", "float"),
+      create_epidata_field_info("rate_age_7", "float"),
+      create_epidata_field_info("rate_age_18t29", "float"),
+      create_epidata_field_info("rate_age_30t39", "float"),
+      create_epidata_field_info("rate_age_40t49", "float"),
+      create_epidata_field_info("rate_age_5t11", "float"),
+      create_epidata_field_info("rate_age_12t17", "float"),
+      create_epidata_field_info("rate_age_lt18", "float"),
+      create_epidata_field_info("rate_age_gte18", "float"),
+      create_epidata_field_info("rate_age_0tlt1", "float"),
+      create_epidata_field_info("rate_age_1t4", "float"),
+      create_epidata_field_info("rate_age_gte75", "float"),
+      create_epidata_field_info("rate_race_white", "float"),
+      create_epidata_field_info("rate_race_black", "float"),
+      create_epidata_field_info("rate_race_hisp", "float"),
+      create_epidata_field_info("rate_race_asian", "float"),
+      create_epidata_field_info("rate_race_natamer", "float"),
+      create_epidata_field_info("rate_sex_male", "float"),
+      create_epidata_field_info("rate_sex_female", "float"),
+      create_epidata_field_info("rate_flu_a", "float"),
+      create_epidata_field_info("rate_flu_b", "float"),
+      create_epidata_field_info("season", "text")
     )
   ) %>% fetch(fetch_args = fetch_args)
 }
@@ -1367,12 +1411,13 @@ pub_flusurv <- function(
 #' @keywords endpoint
 #' @export
 pub_fluview_clinical <- function(
-    regions,
-    epiweeks = "*",
-    ...,
-    issues = NULL,
-    lag = NULL,
-    fetch_args = fetch_args_list()) {
+  regions,
+  epiweeks = "*",
+  ...,
+  issues = NULL,
+  lag = NULL,
+  fetch_args = fetch_args_list()
+) {
   rlang::check_dots_empty()
 
   epiweeks <- get_wildcard_equivalent_dates(epiweeks, "week")
@@ -1474,13 +1519,14 @@ pub_fluview_meta <- function(fetch_args = fetch_args_list()) {
 #' @keywords endpoint
 #' @export
 pub_fluview <- function(
-    regions,
-    epiweeks = "*",
-    ...,
-    issues = NULL,
-    lag = NULL,
-    auth = NULL,
-    fetch_args = fetch_args_list()) {
+  regions,
+  epiweeks = "*",
+  ...,
+  issues = NULL,
+  lag = NULL,
+  auth = NULL,
+  fetch_args = fetch_args_list()
+) {
   rlang::check_dots_empty()
 
   epiweeks <- get_wildcard_equivalent_dates(epiweeks, "week")
@@ -1554,9 +1600,10 @@ pub_fluview <- function(
 #' @keywords endpoint
 #' @export
 pub_gft <- function(
-    locations,
-    epiweeks = "*",
-    fetch_args = fetch_args_list()) {
+  locations,
+  epiweeks = "*",
+  fetch_args = fetch_args_list()
+) {
   epiweeks <- get_wildcard_equivalent_dates(epiweeks, "week")
 
   assert_character_param("locations", locations)
@@ -1599,11 +1646,12 @@ pub_gft <- function(
 #' @keywords endpoint
 #' @export
 pvt_ght <- function(
-    auth,
-    locations,
-    epiweeks = "*",
-    query,
-    fetch_args = fetch_args_list()) {
+  auth,
+  locations,
+  epiweeks = "*",
+  query,
+  fetch_args = fetch_args_list()
+) {
   epiweeks <- get_wildcard_equivalent_dates(epiweeks, "week")
 
   assert_character_param("auth", auth, len = 1)
@@ -1648,12 +1696,13 @@ pvt_ght <- function(
 #' @keywords endpoint
 #' @export
 pub_kcdc_ili <- function(
-    regions,
-    epiweeks = "*",
-    ...,
-    issues = NULL,
-    lag = NULL,
-    fetch_args = fetch_args_list()) {
+  regions,
+  epiweeks = "*",
+  ...,
+  issues = NULL,
+  lag = NULL,
+  fetch_args = fetch_args_list()
+) {
   rlang::check_dots_empty()
 
   epiweeks <- get_wildcard_equivalent_dates(epiweeks, "week")
@@ -1749,9 +1798,10 @@ pub_meta <- function(fetch_args = fetch_args_list()) {
 #' @keywords endpoint
 #' @export
 pub_nidss_dengue <- function(
-    locations,
-    epiweeks = "*",
-    fetch_args = fetch_args_list()) {
+  locations,
+  epiweeks = "*",
+  fetch_args = fetch_args_list()
+) {
   epiweeks <- get_wildcard_equivalent_dates(epiweeks, "week")
 
   assert_character_param("locations", locations)
@@ -1793,12 +1843,13 @@ pub_nidss_dengue <- function(
 #' @keywords endpoint
 #' @export
 pub_nidss_flu <- function(
-    regions,
-    epiweeks = "*",
-    ...,
-    issues = NULL,
-    lag = NULL,
-    fetch_args = fetch_args_list()) {
+  regions,
+  epiweeks = "*",
+  ...,
+  issues = NULL,
+  lag = NULL,
+  fetch_args = fetch_args_list()
+) {
   rlang::check_dots_empty()
 
   epiweeks <- get_wildcard_equivalent_dates(epiweeks, "week")
@@ -1860,10 +1911,11 @@ pub_nidss_flu <- function(
 #' @keywords endpoint
 #' @export
 pvt_norostat <- function(
-    auth,
-    locations,
-    epiweeks = "*",
-    fetch_args = fetch_args_list()) {
+  auth,
+  locations,
+  epiweeks = "*",
+  fetch_args = fetch_args_list()
+) {
   epiweeks <- get_wildcard_equivalent_dates(epiweeks, "week")
 
   assert_character_param("auth", auth, len = 1)
@@ -1906,9 +1958,10 @@ pvt_norostat <- function(
 #' @keywords endpoint
 #' @export
 pub_nowcast <- function(
-    locations,
-    epiweeks = "*",
-    fetch_args = fetch_args_list()) {
+  locations,
+  epiweeks = "*",
+  fetch_args = fetch_args_list()
+) {
   epiweeks <- get_wildcard_equivalent_dates(epiweeks, "week")
 
   assert_character_param("locations", locations)
@@ -1947,12 +2000,13 @@ pub_nowcast <- function(
 #' @keywords endpoint
 #' @export
 pub_paho_dengue <- function(
-    regions,
-    epiweeks = "*",
-    ...,
-    issues = NULL,
-    lag = NULL,
-    fetch_args = fetch_args_list()) {
+  regions,
+  epiweeks = "*",
+  ...,
+  issues = NULL,
+  lag = NULL,
+  fetch_args = fetch_args_list()
+) {
   rlang::check_dots_empty()
 
   epiweeks <- get_wildcard_equivalent_dates(epiweeks, "week")
@@ -2010,10 +2064,11 @@ pub_paho_dengue <- function(
 #' @keywords endpoint
 #' @export
 pvt_quidel <- function(
-    auth,
-    locations,
-    epiweeks = "*",
-    fetch_args = fetch_args_list()) {
+  auth,
+  locations,
+  epiweeks = "*",
+  fetch_args = fetch_args_list()
+) {
   epiweeks <- get_wildcard_equivalent_dates(epiweeks, "week")
 
   assert_character_param("auth", auth, len = 1)
@@ -2069,11 +2124,12 @@ pvt_quidel <- function(
 #' @keywords endpoint
 #' @export
 pvt_sensors <- function(
-    auth,
-    names,
-    locations,
-    epiweeks = "*",
-    fetch_args = fetch_args_list()) {
+  auth,
+  names,
+  locations,
+  epiweeks = "*",
+  fetch_args = fetch_args_list()
+) {
   epiweeks <- get_wildcard_equivalent_dates(epiweeks, "week")
 
   assert_character_param("auth", auth, len = 1)
@@ -2128,12 +2184,13 @@ pvt_sensors <- function(
 #' @keywords endpoint
 #' @export
 pvt_twitter <- function(
-    auth,
-    locations,
-    ...,
-    time_type = c("day", "week"),
-    time_values = "*",
-    fetch_args = fetch_args_list()) {
+  auth,
+  locations,
+  ...,
+  time_type = c("day", "week"),
+  time_values = "*",
+  fetch_args = fetch_args_list()
+) {
   rlang::check_dots_empty()
 
   time_type <- match.arg(time_type)
@@ -2212,13 +2269,14 @@ pvt_twitter <- function(
 #' @keywords endpoint
 #' @export
 pub_wiki <- function(
-    articles,
-    ...,
-    time_type = c("day", "week"),
-    time_values = "*",
-    hours = NULL,
-    language = "en",
-    fetch_args = fetch_args_list()) {
+  articles,
+  ...,
+  time_type = c("day", "week"),
+  time_values = "*",
+  hours = NULL,
+  language = "en",
+  fetch_args = fetch_args_list()
+) {
   rlang::check_dots_empty()
 
   time_type <- match.arg(time_type)
