@@ -517,3 +517,67 @@ test_that("pub_covid_hosp_state_timeseries supports versioned queries", {
   expect_identical(epidata_call$params$as_of, 20220101)
   expect_identical(epidata_call$params$lag, NULL)
 })
+
+test_that("nchs-mortality call fails if time_type not week", {
+  expect_error(pub_covidcast(
+    source = "nchs-mortality",
+    signals = "signal",
+    time_type = "day",
+    geo_type = "state",
+    time_values = "*",
+    geo_values = "*"
+  ), class = "epidatr__nchs_week_only")
+})
+
+test_that("pub_covidcast catches missing args for args without defaults", {
+  expect_no_error(pub_covidcast(
+    source = "jhu-csse",
+    signals = "confirmed_7dav_incidence_prop",
+    time_type = "day",
+    geo_type = "state",
+    fetch_args = fetch_args_list(dry_run = TRUE)
+  ))
+  expect_error(
+    pub_covidcast(
+      signals = "confirmed_7dav_incidence_prop",
+      time_type = "day",
+      geo_type = "state"
+    ),
+    class = "epidatr__pub_covidcast__missing_required_args"
+  )
+  expect_error(
+    pub_covidcast(
+      source = "jhu-csse",
+      time_type = "day",
+      geo_type = "state"
+    ),
+    class = "epidatr__pub_covidcast__missing_required_args"
+  )
+  expect_error(
+    pub_covidcast(
+      source = "jhu-csse",
+      signals = "confirmed_7dav_incidence_prop",
+      geo_type = "state"
+    ),
+    class = "epidatr__pub_covidcast__missing_required_args"
+  )
+  expect_error(
+    pub_covidcast(
+      source = "jhu-csse",
+      signals = "confirmed_7dav_incidence_prop",
+      time_type = "day"
+    ),
+    class = "epidatr__pub_covidcast__missing_required_args"
+  )
+})
+
+test_that("pub_covid_hosp_state_timeseries catches missing args for args without defaults", {
+  expect_no_error(pub_covid_hosp_state_timeseries(
+    states = "fl",
+    fetch_args = fetch_args_list(dry_run = TRUE)
+  ))
+  expect_error(
+    pub_covid_hosp_state_timeseries(),
+    class = "epidatr__pub_covid_hosp_state_timeseries__missing_required_args"
+  )
+})
